@@ -13,13 +13,10 @@
  """
 
 import click
-from pyfiglet import Figlet
 
 '''
 This contains the code snippet for the cli header.
 '''
-f = Figlet(font='slant')
-print (f.renderText('Buildpan'))
 
 
 # cli_commands for the buildpan 
