@@ -3,7 +3,7 @@
     Author: Kushagra A.
     Language: Python
     Date Created: 11-09-2021
-    Date Modified: 22-09-2021
+    Date Modified: 23-09-2021
     Description:
         ###############################################################
         ## Create a file on a specified path   ## 
@@ -12,7 +12,7 @@
 
 from buildpan import find_path
 
-def create_file(project_id, repo_name, path, username):
+def create_file(project_id, repo_name, path, username, provider):
     try:
         find_path.find_path()
         file_path = find_path.find_path.file_path
@@ -27,7 +27,8 @@ def create_file(project_id, repo_name, path, username):
                 "project_id": project_id,
                 "repo_name": repo_name,
                 "path": str(path),
-                "username": username
+                "username": username,
+                "provider": provider
         }
         
         with open(f"{file_path}/info.txt", "r+") as file:
