@@ -12,12 +12,12 @@
 
 
 info = {
-    "HOST" : "35.225.89.124",
-    "PUSH_COMMIT_URL" : "http://35.225.89.124/push_commit",
-    "FETCH_LOG_URL" : "http://35.225.89.124/fetch_log",
-    "GET_SHA_URL" : "http://35.225.89.124/get_sha",
+    "HOST" : "3.6.156.104:5004",
+    "PUSH_COMMIT_URL" : "http://3.6.156.104:5004/push_commit",
+    "FETCH_LOG_URL" : "http://3.6.156.104:5004/fetch_log",
+    "GET_SHA_URL" : "http://3.6.156.104:5004/get_sha",
     "key" : "HB2xRCZSyKYMcTS9rm",
     "secret_key" : "pQA5FMShe6deqr2b8Eq3GfDBmhEnn77C",
-    "version": "1.1"
+    "version": "1.04"
 }
 
