@@ -19,7 +19,7 @@ from buildpan import yaml_reader, find_path
 @click.command()
 def stop():
     '''
-    For deleting a particular repository information
+    For stop CI-CD operation for particular repository
     \f
     
    
@@ -45,4 +45,4 @@ def stop():
 
         #replace file with original name
         os.replace(file_path +'/sample.txt', file_path +'/info.txt')
-        print("Repository Deleted!")
\ No newline at end of file
+        print("CI-CD operation stopped on this repository\n Run:- buildpan init to initiate CI-CD operation")
\ No newline at end of file
